@@ -20,90 +20,64 @@ import glob
 import os.path
 
 import gtweak
-
+from gtweak.utils import SchemaList, LogoutNotification, Notification
 from gi.repository import Gtk
 
 def N_(x): return x
 
-TWEAK_GROUP_FONTS = N_("Fonts")
-TWEAK_GROUP_THEME = N_("Theme")
-TWEAK_GROUP_DESKTOP = N_("Desktop")
-TWEAK_GROUP_WINDOWS = N_("Windows")
-TWEAK_GROUP_SHELL = N_("Shell")
-TWEAK_GROUP_TYPING = N_("Typing")
-TWEAK_GROUP_MOUSE = N_("Mouse")
+TWEAK_GROUP_APPEARANCE = _("Appearance")
+TWEAK_GROUP_EXTENSION = _("Extensions")
+TWEAK_GROUP_FONTS = _("Fonts")
+TWEAK_GROUP_POWER = _("Power")
+TWEAK_GROUP_APPLICATION = _("Startup Applications")
+TWEAK_GROUP_TOPBAR = _("Top Bar")
+TWEAK_GROUP_WINDOWS = _("Windows")
+TWEAK_GROUP_WORKSPACES = _("Workspaces")
 
-#translate this the same as the name of the file manager (nautilus)
-TWEAK_GROUP_FILES = N_("Files")
-
-TWEAK_SORT_FIRST = -1e3
-TWEAK_SORT_LAST = 1e3
+TWEAK_GROUP_MOUSE = _("Mouse")
+TWEAK_GROUP_FILES = _("Files")
 
 LOG = logging.getLogger(__name__)
 
-class Tweak:
+class Tweak(object):
+
     main_window = None
+    widget_for_size_group = None
+
     def __init__(self, name, description, **options):
         self.name = name
         self.description = description
+        self.uid = options.get("uid", self.__class__.__name__)
         self.group_name = options.get("group_name",_("Miscellaneous"))
         self.loaded = options.get("loaded", True)
         self.widget_sort_hint = None
 
         self._search_cache = None
 
-        #FIXME: I would have rather done this as a GObject signal, but it
-        #would prohibit other tweaks from inheriting from GtkWidgets
-        self._notify_cb = None
-
-    @property
-    def widget(self):
-        raise NotImplementedError
-
-    @property
-    def widget_for_size_group(self):
-        return None
-
     def search_matches(self, txt):
         if self._search_cache == None:
-            self._search_cache = set([i.strip(" .,\n'\"").lower() for j in (
-                    self.name.split(' '),self.description.split(' ')) for i in j])
+            self._search_cache = self.name.lower() + " " + self.description.lower()
+        return  txt in self._search_cache
 
-        return txt.strip().lower() in self._search_cache
+    def notify_logout(self):
+        self._logoutnotification = LogoutNotification()
 
-    def set_notify_cb(self, func):
-        self._notify_cb = func
+    def notify_information(self, summary, desc=""):
+        self._notification = Notification(summary, desc)
 
-    def notify_action_required(self, desc, btn, func, error=False):
-        if self._notify_cb:
-            self._notify_cb(self, desc, error, btn, func)
+class TweakGroup(object):
 
-    def notify_error(self, desc):
-        if self._notify_cb:
-            self._notify_cb(self, desc, True, None, None)
+    main_window = None
 
-    def notify_info(self, desc):
-        if self._notify_cb:
-            self._notify_cb(self, desc, False, None, None)
-
-class TweakGroup:
-    def __init__(self, name, *tweaks):
+    def __init__(self, name, *tweaks, **options):
         self.name = name
-        self.tweaks = []
+        self.tweaks = [t for t in tweaks if t.loaded]
+        self.uid = options.get('uid', self.__class__.__name__)
 
-        self._sg = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
-        self._sg.props.ignore_hidden = True
-
-        self.set_tweaks(*tweaks)
-
-    def set_tweaks(self, *tweaks):
-        self.tweaks += [t for t in tweaks if t.loaded]
-
-        for t in tweaks:
-            if not t.loaded:
-                continue
-            if t.widget_for_size_group:
-                self._sg.add_widget(t.widget_for_size_group)
+    def add_tweak(self, tweak):
+        if tweak.loaded:
+            self.tweaks.append(tweak)
+            return True
 
 class TweakModel(Gtk.ListStore):
     (COLUMN_NAME,
@@ -128,17 +102,14 @@ class TweakModel(Gtk.ListStore):
     def tweak_groups(self):
         return (row[TweakModel.COLUMN_TWEAK] for row in self)
 
-    def load_tweaks(self):
-        if 1:
-            tweak_files = [
-                    os.path.splitext(os.path.split(f)[-1])[0]
-                        for f in glob.glob(os.path.join(self._tweak_dir, "tweak_*.py"))]
-        else:
-            tweak_files = ["tweak_test"]
+    def load_tweaks(self, main_window):
+        tweak_files = [
+                os.path.splitext(os.path.split(f)[-1])[0]
+                    for f in glob.glob(os.path.join(self._tweak_dir, "tweak_group_*.py"))]
 
         if not gtweak.ENABLE_TEST:
             try:
-                tweak_files.remove("tweak_test")
+                tweak_files.remove("tweak_group_test")
             except ValueError:
                 pass
         
@@ -148,13 +119,19 @@ class TweakModel(Gtk.ListStore):
         mods = __import__("gtweak.tweaks", globals(), locals(), tweak_files, 0)
         for mod in [getattr(mods, file_name) for file_name in tweak_files]:
             groups.extend( getattr(mod, "TWEAK_GROUPS", []) )
-            tweaks.extend( getattr(mod, "TWEAKS", []) )
-
+            
+        schemas = SchemaList() 
+   
         for g in groups:
-            self.add_tweak_group(g)
-
-        for t in tweaks:
-            self.add_tweak_auto_to_group(t)
+            g.main_window = main_window
+            if g.tweaks:
+                self.add_tweak_group(g)
+                for i in g.tweaks:
+                    i.main_window = main_window
+                    try:
+                        schemas.insert(i.key_name, i.schema_name)
+                    except:
+                        pass
 
     def add_tweak_group(self, tweakgroup):
         if tweakgroup.name in self._tweak_group_names:
@@ -165,20 +142,17 @@ class TweakModel(Gtk.ListStore):
         self._tweak_group_names[tweakgroup.name] = tweakgroup
         self._tweak_group_iters[tweakgroup.name] = _iter
 
-    def add_tweak_auto_to_group(self, tweak):
-        if not tweak.loaded:
-            return
-        name = tweak.group_name
-        try:
-            group = self._tweak_group_names[name]
-        except KeyError:
-            group = TweakGroup(name)
-            self.add_tweak_group(group)
-
-        group.set_tweaks(tweak)
-      
     def search_matches(self, txt):
-        return (t for t in self.tweaks if t.search_matches(txt))
+        tweaks = []                                          
+        groups = []                                                             
+        
+        for g in self.tweak_groups:
+            for t in  g.tweaks:                                             
+                if t.search_matches(txt): 
+                    tweaks.append(t)
+                    if not g.name in groups:                          
+                        groups.append(g.name)
+        return tweaks, groups 
 
     def get_tweakgroup_iter(self, name):
         return self._tweak_group_iters[name]
